
# q-expansion of newform 1071.2.i.g, downloaded from the LMFDB on 19 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 1071
weight = 2
poly_data = [243, -324, 54, 90, -24, -12, -8, 10, 2, -4, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0, 0, 0], 1], [[324, -54, -90, 24, 12, 8, -10, -2, 4, -1], 81], [[810, -594, -189, 219, 39, -26, -38, 11, 17, -5], 162], [[1863, -1701, -342, 552, 69, -71, -89, 38, 32, -17], 162], [[2916, -1728, -765, 483, 183, -22, -130, 19, 43, -13], 162], [[-567, 720, 78, -237, -13, 33, 32, -18, -11, 7], 54], [[-414, 330, 84, -103, -17, 12, 20, -6, -7, 3], 18], [[459, -423, -87, 132, 16, -15, -23, 9, 8, -4], 18], [[-6642, 4995, 1575, -1569, -306, 158, 317, -89, -107, 44], 162]]

hecke_ring_character_values = [[596, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]], [766, [0, 0, 0, 0, -1, 0, 0, 0, 0, 0]], [190, [1, 0, 0, 0, 0, 0, 0, 0, 0, 0]]]
aps_data = [[0, -1, 0, 0, 0, 0, 1, 0, 0, 0], [0, 0, 0, 0, 0, 0, 0, 0, 0, 0], [0, -1, -1, 0, 1, 0, 1, 0, -1, 0], [0, -1, 0, 1, 0, -1, 1, 1, 1, 0], [-2, 0, 0, 1, 2, 1, 0, 1, 0, 0], [1, 2, 0, 0, -1, 2, 0, -1, 1, 0], [1, 0, 0, 0, -1, 0, 0, 0, 0, 0], [1, -1, -2, 0, -1, -1, 2, 2, 0, 0], [0, 0, 1, 0, -5, 0, 0, 0, 1, 0], [4, 2, -3, -1, 0, 0, 4, 0, 4, 1], [-1, 1, -1, -3, 1, 0, 1, 0, 0, 0], [-1, 4, 2, 0, -2, 1, -5, -2, 1, 1], [-1, 2, 0, -1, -1, 2, -1, -1, 0, 1], [4, -1, -5, -3, 2, -4, 5, 2, 3, 3], [-1, 2, 2, 0, 1, 1, -3, -2, 0, 0], [-1, 0, 0, 3, 1, 0, -1, 0, 1, 0], [-4, 2, -2, -1, 4, 0, 3, 0, -1, 0], [1, -2, -1, 0, -5, -1, 3, 2, 0, -1], [-3, -1, 1, -5, 3, -1, 1, -1, -2, 0], [5, 0, -3, -2, 0, 0, 1, 0, 1, 2], [-3, 0, 0, 1, 3, 2, 2, 2, -2, 0], [1, 0, 1, 0, -1, -1, 1, 2, 4, 1], [-3, 4, 4, -1, -3, 6, -7, -3, -4, 1], [-2, 3, 3, 0, 0, 2, -5, -4, -2, -1], [3, -4, 5, 7, 1, -2, 0, 1, -1, -7], [1, -5, 5, -1, -1, -3, -1, -3, -4, 0], [0, 2, -4, 0, 0, 0, -2, 0, 0, 4], [0, 0, -1, 0, 3, 0, 0, 0, -2, -1], [-2, 0, 0, 0, 2, 2, -3, 2, 3, 0], [9, -2, -2, -3, 0, 0, -3, 0, -3, 3], [-4, 7, 3, -2, -4, 8, -6, -4, -2, 2], [2, 1, -8, 0, -3, -2, 1, 4, -1, 3], [2, 4, -4, -3, -2, 3, 1, 3, 3, 0], [1, -1, 4, 2, -4, 8, -11, -4, -7, -2], [2, -8, -1, 0, 3, -2, 10, 4, 5, 2], [-1, 4, -4, -3, 1, 2, 3, 2, 1, 0], [-3, 3, -3, -1, 3, -2, 3, -2, 0, 0], [1, -2, -2, 0, 0, -1, 3, 2, 3, 3], [-4, 6, 4, -3, 0, 0, -1, 0, -1, 3], [4, -6, -7, 0, 6, -4, 10, 8, 7, 6], [-2, -2, 2, 1, 2, -4, 0, -4, -2, 0], [3, -2, 3, -1, 3, -6, 0, 3, -3, 1], [3, -5, -10, 0, 8, -3, 8, 6, 3, 7], [-5, 5, -5, -3, 5, -1, 3, -1, 2, 0], [2, 2, 5, 3, -2, 4, -4, -2, -2, -3], [6, -1, 1, -2, -6, 2, 1, 2, -2, 0], [-1, 4, -2, -5, -1, 2, -1, -1, 0, 5], [7, 6, 1, -5, -4, 8, -8, -4, -4, 5], [-2, -4, 4, 2, 2, 2, -3, 2, -1, 0], [-2, 1, 0, 0, -16, 2, -3, -4, -3, 1], [-4, 3, 10, 0, -6, 4, -7, -8, -2, -4], [12, -10, -11, 1, 5, -10, 12, 5, 7, -1], [6, 1, -1, 4, -6, 3, -2, 3, 3, 0], [-10, -1, 2, -3, 1, -2, -4, 1, -5, 3], [2, 2, -2, 0, -2, -2, 0, 4, 2, 0], [-3, 1, -1, -4, 3, -6, 2, -6, -1, 0], [11, -3, 3, -1, -11, 2, 3, 2, -6, 0], [2, -5, 2, 0, 3, -2, 7, 4, 8, 2], [6, -7, 7, 6, -6, 3, -8, 3, 1, 0], [-8, 1, -3, 0, 0, 0, 4, 0, 4, 0], [2, -1, 1, 1, -2, 1, -4, 1, 3, 0], [5, 1, 2, -2, -4, 8, -11, -4, -7, 2], [-2, 8, 8, -2, -1, 2, -4, -1, -3, 2], [3, -4, 4, -3, -3, 0, 4, 0, -8, 0], [-1, -1, 0, 0, -1, 1, 0, -2, 1, 3], [-4, 17, 4, 0, -2, 4, -21, -8, -4, 0], [-3, 8, 1, 0, -13, 3, -11, -6, -3, 2], [0, 3, -9, 0, -1, 2, 10, -1, 11, 0], [-15, -9, 9, 0, 15, 0, -4, 0, -5, 0], [10, 1, 4, -4, -4, 8, -15, -4, -11, 4], [6, -6, 6, 5, -6, 1, -4, 1, -2, 0], [-3, 3, 7, 0, 7, 3, -6, -6, -2, -3], [8, 7, -7, -2, -8, 7, 4, 7, 3, 0], [-1, 4, -3, 0, -6, 1, -5, -2, -5, 0], [-4, -6, 8, 4, 1, -2, -8, 1, -9, -4], [-3, -2, 9, 0, 5, 3, -1, -6, 0, -3], [9, 0, 0, -3, -9, 6, -2, 6, 2, 0], [2, -1, -4, 0, -13, -2, 3, 4, 4, 4], [2, -2, 4, 0, -6, -2, 4, 4, 5, -3], [12, -1, 1, -5, -12, -2, -4, -2, 3, 0], [-7, -6, -3, 5, 5, -10, 12, 5, 7, -5], [-4, -6, 9, 8, 4, -8, 1, 4, -3, -8], [9, 9, -9, -1, -9, 9, 4, 9, 5, 0], [-2, -5, -8, 1, 3, -6, 10, 3, 7, -1], [8, -5, -2, 0, -8, -8, 13, 16, 15, 1], [4, 6, -5, 0, 0, -4, -2, 8, 3, 0], [-15, 0, 1, 2, -3, 6, -5, -3, -2, -2], [-5, 11, 14, 0, -14, 5, -16, -10, -8, -12], [-1, -1, -6, -7, 2, -4, 2, 2, 0, 7], [7, -2, -19, -7, 5, -10, 20, 5, 15, 7], [1, -9, -2, 0, -4, -1, 10, 2, -2, -2], [-10, 1, -1, 1, 10, 4, -1, 4, 2, 0], [5, 12, -12, -6, -5, -4, 1, -4, 11, 0], [2, 1, -15, -7, 1, -2, 11, 1, 10, 7], [-5, 6, -2, 0, 7, 5, -11, -10, -5, 7], [-5, 0, 19, 12, -1, 2, -9, -1, -8, -12], [-1, 0, 11, 0, 15, 1, -1, -2, -3, -12], [20, 11, -11, -5, -20, -2, 6, -2, 5, 0], [0, 5, 8, 0, -13, 0, -5, 0, 3, -5], [1, 0, -16, 0, 2, -1, 1, 2, 0, 14], [9, -3, 9, 12, 1, -2, 2, 1, 1, -12], [-8, -2, 2, 0, 8, 2, 7, 2, -9, 0], [-5, 10, -10, -5, 5, -2, 1, -2, 9, 0], [2, -3, 3, 0, -10, -2, 5, 4, 2, -5], [3, -10, 10, 1, -3, 0, -6, 0, -4, 0], [-9, 3, -3, -6, 9, -9, 6, -9, -3, 0], [6, -5, -5, 2, 3, -6, 8, 3, 5, -2], [0, -1, 0, 0, -19, 0, 1, 0, 6, 6], [-13, 3, -3, -1, 13, -4, -2, -4, 5, 0], [-2, -9, 7, 4, 6, -12, 0, 6, -6, -4], [4, -7, -5, 0, 29, -4, 11, 8, 3, 0], [-10, 9, -9, 5, 10, 0, 4, 0, 5, 0], [-15, 5, 1, 7, 1, -2, 13, 1, 12, -7], [-1, -1, 1, -5, 1, 5, 1, 5, -2, 0], [0, 4, -8, -2, -5, 10, 0, -5, 5, 2], [7, -9, 9, -4, -7, 0, -4, 0, -5, 0], [11, 6, -20, -9, 4, -8, 25, 4, 21, 9], [2, 1, -1, 9, -2, -5, -2, -5, 3, 0], [3, -1, -3, 0, 0, -3, 4, 6, -6, -9], [9, 1, -7, -7, 4, -8, 9, 4, 5, 7], [-17, 2, -2, 2, 17, 2, 0, 2, 2, 0], [-2, 5, -23, -15, 2, -4, 17, 2, 15, 15], [0, 0, 0, 0, 6, 0, 0, 0, 0, 0], [25, -7, 7, 1, -25, 7, -6, 7, -1, 0], [-6, 11, -1, 0, 15, 6, -17, -12, -13, 0], [8, 10, -8, -5, 1, -2, 15, 1, 14, 5], [-2, -2, 6, 0, 10, 2, 0, -4, 0, -2], [-4, 2, -10, 0, 8, 4, -6, -8, -9, 9], [1, 3, -12, 0, 3, -6, 21, 3, 18, 0], [2, 8, -4, 0, -4, -2, -6, 4, -1, -1], [-21, -2, 2, 0, 21, 1, 7, 1, -9, 0], [0, -1, 11, 6, -2, 4, -10, -2, -8, -6], [3, -6, -7, 0, -14, -3, 9, 6, -5, -4], [5, 1, 13, 4, -3, 6, -14, -3, -11, -4], [2, -11, -10, 0, 23, -2, 13, 4, -4, 2], [1, 8, 1, -4, -1, 2, 1, -1, 2, 4], [-4, 10, -10, 4, 4, 4, 3, 4, 7, 0], [-14, -12, 12, 4, 14, -1, -13, -1, 1, 0], [-8, -7, 1, 1, 4, -8, 1, 4, -3, -1], [0, 2, -2, -12, 0, -12, 4, -12, -2, 0], [16, -8, 5, 12, 2, -4, 3, 2, 1, -12], [-11, 7, 4, 0, -1, 11, -18, -22, -8, 10], [-7, -14, 14, 1, 7, -5, 1, -5, -15, 0], [1, 9, 4, -4, 2, -4, 5, 2, 3, 4], [-15, 4, -4, 7, 15, 4, 4, 4, 0, 0], [-11, 10, 3, -4, -7, 14, -11, -7, -4, 4], [-3, -15, 6, 3, 2, -4, -14, 2, -16, -3], [7, 5, -5, -6, -7, -7, 11, -7, -6, 0], [0, 1, 6, 0, -21, 0, -1, 0, 4, -2], [8, -4, -5, 0, -19, -8, 12, 16, 13, 2], [-8, 24, 15, 0, -27, 8, -32, -16, -4, -3], [-19, -3, 17, 12, 1, -2, -6, 1, -7, -12], [-5, 10, -15, -10, 2, -4, 19, 2, 17, 10], [3, 1, 0, 0, -9, -3, 2, 6, 5, -1], [5, 17, -17, -1, -5, 2, 7, 2, 10, 0], [3, -13, -8, -7, 6, -12, 0, 6, -6, 7], [-4, -1, 6, 0, 1, 4, -3, -8, 3, 5], [-2, 6, 5, 0, 26, 2, -8, -4, -2, -3], [15, -6, 9, 6, -1, 2, -11, -1, -10, -6], [-1, -12, 12, 15, 1, -2, -1, -2, -11, 0], [2, 3, -7, 0, 16, -2, -1, 4, -1, 2], [-25, -4, 11, 10, 0, 0, -5, 0, -5, -10], [12, -6, -14, 1, 0, 0, 9, 0, 9, -1], [5, -22, -6, 0, -8, -5, 27, 10, 1, -3], [18, 6, -6, 5, -18, 1, 2, 1, 4, 0], [5, -2, 2, 5, -5, 2, -9, 2, 7, 0], [14, 5, -5, -7, -14, 1, 7, 1, -2, 0], [12, -18, 18, 2, -12, 4, -3, 4, -15, 0], [22, -4, -2, -3, -4, 8, -13, -4, -9, 3], [0, 5, 17, 0, -11, 0, -5, 0, 2, -15], [-7, 15, -15, -9, 7, -4, 9, -4, 6, 0], [29, 3, 2, 7, -4, 8, 0, -4, 4, -7], [-7, 13, -4, 0, 23, 7, -20, -14, -14, 4], [7, -7, 7, -8, -7, 9, 4, 9, -11, 0], [-7, 13, -13, -2, 7, -4, 11, -4, 2, 0], [21, -1, -33, -9, 6, -12, 35, 6, 29, 9], [-36, 13, 27, 11, -13, 26, -29, -13, -16, -11], [11, 0, 0, 7, -11, 7, -9, 7, 9, 0], [-26, 17, 7, -9, -6, 12, -11, -6, -5, 9], [1, -11, -12, 0, -21, -1, 12, 2, -9, 1], [-11, 2, 9, 0, 11, 11, -13, -22, -20, -7], [-10, 24, 12, -10, -7, 14, -12, -7, -5, 10], [-16, 8, 2, -7, -1, 2, -3, -1, -2, 7], [-8, -5, 20, 0, 13, 8, -3, -16, -3, -7], [8, 9, -9, 5, -8, 7, 9, 7, 0, 0], [14, 0, 0, -13, -14, 9, 8, 9, -8, 0], [-6, -3, 3, 13, 6, -4, -10, -4, 7, 0], [1, 26, -26, 3, -1, -2, 6, -2, 20, 0], [-5, -5, 6, 0, -1, 5, 0, -10, -3, 1], [-6, 9, -9, 1, 6, 0, 10, 0, -1, 0], [3, 9, 12, 0, -5, -3, -6, 6, 18, 0], [21, -7, 2, -2, 8, -16, 5, 8, -3, 2], [-3, -6, -2, 0, 0, 3, 3, -6, -6, 2], [-1, 14, 8, 0, 8, 1, -15, -2, 6, 0], [-4, 7, -7, -9, 4, 6, 6, 6, 1, 0], [-13, 1, -1, -6, 13, -5, 0, -5, 1, 0], [-6, -12, 12, 7, 6, 5, -9, 5, -3, 0], [4, -5, -4, 0, 23, -4, 9, 8, 13, 9], [14, -17, -7, -4, -3, 6, -20, -3, -17, 4], [7, 5, -9, 0, -7, -7, 2, 14, 11, 6], [-13, -5, 5, -4, 13, 1, 7, 1, -12, 0], [20, -3, -15, -12, 0, 0, 0, 0, 0, 12], [2, 1, -23, 0, 10, -2, 1, 4, 1, 20], [-1, 2, -2, -14, 1, -5, 5, -5, -3, 0], [-24, -6, 17, 6, 1, -2, -15, 1, -16, -6], [2, 12, -12, 8, -2, -2, 9, -2, 3, 0], [1, -13, -8, 0, -5, -1, 14, 2, 6, 12], [-1, -2, -11, 0, -10, 1, 1, -2, 6, 19], [-23, 10, 10, 6, 1, -2, 8, 1, 7, -6], [-3, -2, 2, -12, 3, -5, 8, -5, -10, 0], [6, -14, -6, 0, 12, -6, 20, 12, 19, 13], [-8, -5, 21, 6, -1, 2, -22, -1, -21, -6], [4, -14, 1, 10, 2, -4, -1, 2, -3, -10], [-7, 0, 11, 0, -14, 7, -7, -14, -13, -10], [-8, 19, -19, 9, 8, 2, 12, 2, 7, 0], [-6, 15, 0, 0, -9, 6, -21, -12, -17, -5], [-6, -5, 5, 18, 6, 7, 2, 7, -7, 0], [-5, -13, 13, 13, 5, 1, 0, 1, -13, 0], [-6, 9, 10, 0, -13, 6, -15, -12, -17, -15], [-10, 13, 13, -5, -5, 10, -15, -5, -10, 5], [-3, 13, 8, 0, 28, 3, -16, -6, 2, 0], [-18, -5, -18, 5, 8, -16, 34, 8, 26, -5], [-3, -7, 10, 0, 19, 3, 4, -6, 6, 2], [-1, -11, 6, 0, -12, 1, 10, -2, 2, -2], [22, 14, -1, -5, -3, 6, 4, -3, 7, 5], [3, 13, 3, -8, -5, 10, -8, -5, -3, 8], [-13, 5, 24, 0, -8, 13, -18, -26, -9, -7], [17, 8, -8, 8, -17, 9, 0, 9, 8, 0], [-5, 2, 20, 0, 6, 5, -7, -10, 0, -10], [9, -4, -33, 0, 21, -9, 13, 18, -2, 13], [12, 1, -1, -5, -12, 0, -8, 0, 9, 0], [24, -3, 3, 1, -24, 9, -12, 9, 9, 0], [27, -3, -22, -10, 6, -12, 21, 6, 15, 10], [-14, 3, -3, -7, 14, 2, 6, 2, -3, 0], [22, -7, 9, 11, -1, 2, -7, -1, -6, -11], [-42, -13, 13, 6, 42, 0, -8, 0, -5, 0], [6, -18, 9, 0, -13, -6, 24, 12, 12, -9], [15, -14, -17, 0, 6, -15, 29, 30, 34, 21], [-12, 4, 8, 6, -6, 12, -10, -6, -4, -6], [-18, 8, -1, 0, -4, 8, 1, -4, 5, 0], [-3, 13, -13, -1, 3, 15, 6, 15, 7, 0], [7, -10, 1, 0, 17, -7, 17, 14, 4, -11], [-1, -9, 9, 0, 1, -2, 2, -2, -11, 0], [-1, 0, -7, 0, 2, 1, -1, -2, -16, -7], [3, -10, 19, 12, 6, -12, -5, 6, -11, -12], [-9, 22, 17, 0, -27, 9, -31, -18, -1, 0], [-14, -3, -6, -8, 11, -22, 17, 11, 6, 8], [23, 7, -7, 8, -23, 6, -10, 6, 17, 0], [3, 15, -15, -7, -3, 9, 17, 9, -2, 0], [16, 12, -9, -15, -1, 2, 4, -1, 5, 15], [-4, 9, -1, -11, -2, 4, -5, -2, -3, 11], [-3, -10, -3, 0, 12, 3, 7, -6, -3, 6], [-1, -4, 4, 14, 1, -6, -5, -6, 1, 0], [-17, 9, 2, 1, -5, 10, -2, -5, 3, -1], [-27, -5, 5, -20, 27, 4, 14, 4, -19, 0], [11, -13, -7, 0, -11, -11, 24, 22, 14, -1], [22, 11, -11, 7, -22, -4, -3, -4, 14, 0], [20, -6, 6, -10, -20, -5, 3, -5, -9, 0], [-12, -22, 6, 14, 9, -18, 4, 9, -5, -14], [-10, 6, 24, 0, -17, 10, -16, -20, 2, -2], [-26, -7, 7, 5, 26, 5, 6, 5, -13, 0], [25, 8, -6, 2, 0, 0, 16, 0, 16, -2], [0, 26, -26, 0, 0, 0, 6, 0, 20, 0], [20, 10, -8, -12, 5, -10, 16, 5, 11, 12], [21, 4, -4, -13, -21, -13, -4, -13, 8, 0], [7, -14, -4, 0, 22, -7, 21, 14, 9, -1], [-26, 2, -24, -22, 0, 0, 4, 0, 4, 22], [34, 1, -11, -11, 2, -4, 5, 2, 3, 11], [28, -1, 18, 7, 0, 0, -12, 0, -12, -7], [8, 8, -8, -7, -8, -13, -2, -13, 10, 0], [-13, 19, 22, 0, -23, 13, -32, -26, -11, -7], [-14, 4, -4, 1, 14, -9, -10, -9, 14, 0], [-1, -11, 11, -15, 1, 2, 0, 2, -11, 0], [8, -2, -3, 0, 19, -8, 10, 16, 8, -5], [17, -16, 4, 0, 15, -30, 10, 15, -5, 0], [-10, 4, 31, 0, -15, 10, -14, -20, -5, -16], [6, -10, -4, 0, 4, -6, 16, 12, -5, -13], [11, -8, 8, 13, -11, -1, -10, -1, 2, 0], [-6, -1, 1, 0, 21, 6, -5, -12, -19, -8], [2, 8, 10, 0, 37, -2, -6, 4, -1, -15], [0, 6, -6, -16, 0, 2, -3, 2, 9, 0], [-17, -18, 18, 4, 17, 4, 6, 4, -24, 0], [-12, -5, 11, 13, -5, 10, -13, -5, -8, -13], [-12, 14, 20, 16, -8, 16, -6, -8, 2, -16], [-5, 10, 21, 0, 19, 5, -15, -10, 9, -2], [-7, 7, 22, 0, -5, 7, -14, -14, -2, -10], [9, 19, -19, -16, -9, -10, 7, -10, 12, 0], [21, -22, -18, 0, 6, -12, 8, 6, 2, 0], [25, 7, -7, -4, -25, 14, 3, 14, 4, 0], [-13, 4, 29, 17, -12, 24, -32, -12, -20, -17], [-27, 1, -1, -8, 27, -5, 8, -5, -7, 0], [-20, -9, 9, 9, 20, 10, 0, 10, -9, 0], [-3, 0, 18, 0, 42, 3, -3, -6, 3, -9], [-3, -3, 2, -1, 7, -14, 8, 7, 1, 1], [-23, 22, 31, 1, -7, 14, -22, -7, -15, -1], [12, -1, 1, 14, -12, -4, -5, -4, 4, 0], [-7, 21, 16, 0, -15, 7, -28, -14, -10, -12], [13, 17, 12, -5, -16, 32, -32, -16, -16, 5], [-1, 11, -15, 0, 0, 1, -12, -2, -8, 9], [-16, -10, 0, -14, 10, -20, -4, 10, -14, 14], [5, 1, 10, 0, 4, -5, 4, 10, 10, -10], [-5, 0, 36, 0, -30, 5, -5, -10, 7, -19], [-12, -15, 15, 12, 12, 2, -20, 2, 5, 0]]
